﻿Public Class Form1

    Private icoParser As New ICOFileParser()
    Private PictureBox As New PictureBox()
    Private OpenFileDialog As New OpenFileDialog()
    Private iconListBox As New ListBox()
    Private lblIconInfo As New Label()
    Private btnExport As New Button()
    Private statusStrip As New StatusStrip()
    Public toolStripStatusLabel As New ToolStripStatusLabel()

    Public Sub New()
        ' Set up form properties
        Me.Text = "ICO File Viewer"
        Me.ClientSize = New Size(800, 500)
        Me.StartPosition = FormStartPosition.CenterScreen

        ' Set up the PictureBox
        PictureBox.Dock = DockStyle.Fill
        PictureBox.SizeMode = PictureBoxSizeMode.CenterImage
        Me.Controls.Add(PictureBox)

        ' Set up the ListBox for icons
        iconListBox.Dock = DockStyle.Left
        iconListBox.Width = 150
        iconListBox.DisplayMember = "Key" ' To show icon size (Key)
        AddHandler iconListBox.SelectedIndexChanged, AddressOf IconListBox_SelectedIndexChanged
        Me.Controls.Add(iconListBox)

        ' Set up the label to show icon information
        lblIconInfo.Dock = DockStyle.Bottom
        lblIconInfo.Height = 30
        lblIconInfo.TextAlign = ContentAlignment.MiddleCenter
        Me.Controls.Add(lblIconInfo)

        ' Add a StatusStrip for status messages
        statusStrip.Items.Add(toolStripStatusLabel)
        Me.Controls.Add(statusStrip)

        ' Set up the OpenFileDialog
        OpenFileDialog.Filter = "ICO Files|*.ico|All Files|*.*"
        OpenFileDialog.Title = "Open ICO File"

        ' Add a button to open ICO file
        Dim btnOpen As New Button() With {
            .Text = "Open ICO File",
            .Dock = DockStyle.Top
        }
        AddHandler btnOpen.Click, AddressOf OpenFileButton_Click
        Me.Controls.Add(btnOpen)

        ' Add Export button
        btnExport.Text = "Export Icon"
        btnExport.Dock = DockStyle.Top
        btnExport.Enabled = False ' Initially disabled
        AddHandler btnExport.Click, AddressOf ExportIconButton_Click
        Me.Controls.Add(btnExport)

        ' Enable drag and drop
        Me.AllowDrop = True
        AddHandler Me.DragEnter, AddressOf Form_DragEnter
        AddHandler Me.DragDrop, AddressOf Form_DragDrop
    End Sub

    Private Sub OpenFileButton_Click(sender As Object, e As EventArgs)
        Using openFileDialog As New OpenFileDialog()
            openFileDialog.Filter = "ICO Files|*.ico"
            If openFileDialog.ShowDialog() = DialogResult.OK Then
                ' Clear any previous icons
                iconListBox.Items.Clear()
                PictureBox.Image = Nothing
                lblIconInfo.Text = ""
                toolStripStatusLabel.Text = "Loading icons..."

                Try
                    ' Load the icons from the ICO file
                    Dim icons As List(Of Icon) = icoParser.ExtractIcons(openFileDialog.FileName)
                    If icons.Count > 0 Then
                        ' Populate the ListBox with icon sizes (key: size)
                        For Each icon As Icon In icons
                            iconListBox.Items.Add(New KeyValuePair(Of String, Icon)(icon.Width & "x" & icon.Height, icon))
                        Next
                        ' Convert the first icon to a Bitmap and display it
                        PictureBox.Image = icons(0).ToBitmap()
                        toolStripStatusLabel.Text = "Icons loaded successfully."
                    Else
                        MessageBox.Show("No icons found in the ICO file.")
                        toolStripStatusLabel.Text = "No icons found in the ICO file."
                    End If
                Catch ex As Exception
                    MessageBox.Show("Error loading ICO file: " & ex.Message)
                    toolStripStatusLabel.Text = "Error loading ICO file."
                End Try
            End If
        End Using
    End Sub

    Private Sub IconListBox_SelectedIndexChanged(sender As Object, e As EventArgs)
        ' Display selected icon in PictureBox
        If iconListBox.SelectedItem IsNot Nothing Then
            Dim selectedIcon As Icon = CType(iconListBox.SelectedItem, KeyValuePair(Of String, Icon)).Value
            PictureBox.Image = selectedIcon.ToBitmap()

            ' Display icon info (size and color depth)
            lblIconInfo.Text = "Size: " & selectedIcon.Width & "x" & selectedIcon.Height & " | Depth: " & selectedIcon.GetBitDepth() & " bits"

            ' Enable Export button
            btnExport.Enabled = True
        End If
    End Sub

    Private Sub ExportIconButton_Click(sender As Object, e As EventArgs)
        ' Ask the user where to save the file
        Using saveFileDialog As New SaveFileDialog()
            saveFileDialog.Filter = "PNG Files|*.png|JPEG Files|*.jpg|BMP Files|*.bmp"
            If saveFileDialog.ShowDialog() = DialogResult.OK Then
                Try
                    ' Export the current icon as an image
                    Dim selectedIcon As Icon = CType(iconListBox.SelectedItem, KeyValuePair(Of String, Icon)).Value
                    Dim bmp As Bitmap = selectedIcon.ToBitmap()

                    ' Save the selected icon in the chosen format
                    If saveFileDialog.FilterIndex = 1 Then
                        bmp.Save(saveFileDialog.FileName, System.Drawing.Imaging.ImageFormat.Png)
                    ElseIf saveFileDialog.FilterIndex = 2 Then
                        bmp.Save(saveFileDialog.FileName, System.Drawing.Imaging.ImageFormat.Jpeg)
                    Else
                        bmp.Save(saveFileDialog.FileName, System.Drawing.Imaging.ImageFormat.Bmp)
                    End If
                    MessageBox.Show("Icon exported successfully!")
                    toolStripStatusLabel.Text = "Icon exported successfully!"
                Catch ex As Exception
                    MessageBox.Show("Error exporting icon: " & ex.Message)
                    toolStripStatusLabel.Text = "Error exporting icon."
                End Try
            End If
        End Using
    End Sub

    Private Sub Form_DragEnter(sender As Object, e As DragEventArgs)
        If e.Data.GetDataPresent(DataFormats.FileDrop) Then
            e.Effect = DragDropEffects.Copy
        Else
            e.Effect = DragDropEffects.None
        End If
    End Sub

    Private Sub Form_DragDrop(sender As Object, e As DragEventArgs)
        Dim files As String() = CType(e.Data.GetData(DataFormats.FileDrop), String())
        If files.Length > 0 Then
            OpenFileButton_Click(sender, e) ' Call OpenFileButton_Click with the dragged file
        End If
    End Sub

End Class
